pub struct HijriYearData {
packed: PackedHijriYearData,
extended_year: i32,
}Expand description
Information about a Hijri year.
Fields
packed: PackedHijriYearDataextended_year: i32Implementations
Sourceimpl HijriYearData
impl HijriYearData
Sourcepub fn try_new(
extended_year: i32,
start_day: RataDie,
month_lengths: [bool; 12],
) -> Option<Self>
pub fn try_new( extended_year: i32, start_day: RataDie, month_lengths: [bool; 12], ) -> Option<Self>
Creates HijriYearData from the given parts.
start_day is the date for the first day of the year, see Date::to_rata_die
to obtain a RataDie from a Date in an arbitrary calendar. start_day has
to be within 5 days of the start of the year of the TabularAlgorithm.
month_lengths[n - 1] is true if the nth month has 30 days, and false otherwise.
Either 6 or 7 months need to have 30 days.
fn lookup( extended_year: i32, starting_year: i32, data: &[PackedHijriYearData], ) -> Option<Self>
fn new_year(self) -> RataDie