pub struct TabularAlgorithm {
pub(crate) leap_years: TabularAlgorithmLeapYears,
pub(crate) epoch: TabularAlgorithmEpoch,
}Expand description
Hijri Rules for the Tabular Hijri Algorithm.
See TabularAlgorithmEpoch and TabularAlgorithmLeapYears for customization.
The most common version of these rules uses TabularAlgorithmEpoch::Friday and TabularAlgorithmLeapYears::TypeII.
When constructed with TabularAlgorithmLeapYears::TypeII, and either TabularAlgorithmEpoch::Friday or TabularAlgorithmEpoch::Thursday,
this corresponds to the "islamic-civil" and "islamic-tbla" CLDR calendars respectively.
Fields
leap_years: TabularAlgorithmLeapYearsepoch: TabularAlgorithmEpochImplementations
Sourceimpl TabularAlgorithm
impl TabularAlgorithm
Sourcepub const fn new(
leap_years: TabularAlgorithmLeapYears,
epoch: TabularAlgorithmEpoch,
) -> Self
pub const fn new( leap_years: TabularAlgorithmLeapYears, epoch: TabularAlgorithmEpoch, ) -> Self
Construct a new TabularAlgorithm with the given leap year rule and epoch.